@@ -11,7 +11,7 @@ resid_median <- function (obj, resid, plot = TRUE, value=3, title,
 # local functions 
 gamlss_prep_data <- function (obj, value=2) 
 {
-    sdres <- obj$residuals
+    sdres <- residuals(obj)
        fv <- quantile_gamlss(obj, quantile=0.5)
 #sdres_out <- abs(sdres) > value
       obs <- seq_len(length(sdres))
@@ -46,8 +46,7 @@ return(out)
 ################################################################################
   # the main function starts here  
 if (missing(obj)&&missing(resid))  stop("A GAMLSS fitted object or the argument resid should be used")
-if (!missing(obj)&&!is.gamlss(obj)) stop("the model is not a gamlss model")
-  
+  if (!missing(obj)&&!(is.gamlss(obj)|is(obj, "gamlss2"))) stop("the model is not a gamlss model")
 d <- if (missing(obj)) other_prep_data(resid, value=value) 
      else             gamlss_prep_data(obj,   value=value) 
 txt.title <- if (missing(title))  paste("Residuals & fitted vals of model",deparse(substitute(obj)))
